# AUC_NRI_IDI_python_functions
[![DOI](https://zenodo.org/badge/365029676.svg)](https://zenodo.org/doi/10.5281/zenodo.4741234)

Custom python functions to help you further analyse machine learning models and diagnostic test.

Will help you make plots and compute evaluation metrics as seen in [Nature Article, Leong et al. 2021](https://www.nature.com/articles/s43856-021-00024-0?source=post_page-----f87a8ec6937b--------------------------------#Fig3)

![From Leong et. al. 2021](idi_auc.png)

Functions to compute and plot:
* AUC = Area Under the Curve
* NRI = Net Reclassification Index
* IDI = Integrated Discrimination Improvement

Run "example.ipynb" Jupyter notebook to see and use functions

Code and concepts further explained in the following post: "[Area Under the Curve and Beyond](https://www.lambertleong.com/thoughts/AUC-IDI-NRI)" or "[On Medium/Towards Data Science](https://medium.com/towards-data-science/area-under-the-curve-and-beyond-f87a8ec6937b)"

---
contact [Lambert Leong](https://www.lambertleong.com)
